==> datadog-api-client-1.10.0.tar.gz: datadog-api-client-1.10.0/src/datadog_api_client/v1/model/logs_by_retention_monthly_usage.py <==
# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


from datadog_api_client.v1.model_utils import (
    ModelNormal,
    cached_property,
)


def lazy_import():
    from datadog_api_client.v1.model.logs_retention_sum_usage import LogsRetentionSumUsage

    globals()["LogsRetentionSumUsage"] = LogsRetentionSumUsage


class LogsByRetentionMonthlyUsage(ModelNormal):

    validations = {}

    @cached_property
    def openapi_types():
        lazy_import()
        return {
            "date": (str,),
            "usage": ([LogsRetentionSumUsage],),
        }

    attribute_map = {
        "date": "date",
        "usage": "usage",
    }

    read_only_vars = {}

    def __init__(self, *args, **kwargs):
        """
        Object containing a summary of indexed logs usage by retention period for a single month.

        :param date: The month for the usage.
        :type date: str, optional

        :param usage: Indexed logs usage for each active retention for the month.
        :type usage: [LogsRetentionSumUsage], optional
        """
        super().__init__(kwargs)

        self._check_pos_args(args)

    @classmethod
    def _from_openapi_data(cls, *args, **kwargs):
        """Helper creating a new instance from a response."""

        self = super(LogsByRetentionMonthlyUsage, cls)._from_openapi_data(kwargs)

        self._check_pos_args(args)

        return self

==> datadog-api-client-1.11.0.tar.gz: datadog-api-client-1.11.0/src/datadog_api_client/v1/model/logs_by_retention_monthly_usage.py <==
# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    datetime,
)


def lazy_import():
    from datadog_api_client.v1.model.logs_retention_sum_usage import LogsRetentionSumUsage

    globals()["LogsRetentionSumUsage"] = LogsRetentionSumUsage


class LogsByRetentionMonthlyUsage(ModelNormal):
    @cached_property
    def openapi_types(_):
        lazy_import()
        return {
            "date": (datetime,),
            "usage": ([LogsRetentionSumUsage],),
        }

    attribute_map = {
        "date": "date",
        "usage": "usage",
    }

    def __init__(self, *args, **kwargs):
        """
        Object containing a summary of indexed logs usage by retention period for a single month.

        :param date: The month for the usage.
        :type date: datetime, optional

        :param usage: Indexed logs usage for each active retention for the month.
        :type usage: [LogsRetentionSumUsage], optional
        """
        super().__init__(kwargs)

        self._check_pos_args(args)

    @classmethod
    def _from_openapi_data(cls, *args, **kwargs):
        """Helper creating a new instance from a response."""

        self = super(LogsByRetentionMonthlyUsage, cls)._from_openapi_data(kwargs)

        self._check_pos_args(args)

        return self
